import React from 'react';
import {
  View,
  ActivityIndicator,
} from 'react-native';
import styled from 'styled-components/native';
import TextComponent from './TextComponent';

const CustomButton = styled.TouchableHighlight`
  background: ${props => props.alternative
          ? 'transparent'
          : props.theme.mainFirst};
  border-style: solid;
  border-width: ${props => props.alternative ? '1px' : '0px'};
  border-color: ${props => props.alternative
          ? props.theme.mainFirst
          : 'transparent'};
  height: 45px;
  display: flex;
  width: ${props => props.width ? props.width : '80%'};
  justify-content: center;
  align-items: center;
  border-radius: 10px;
  margin-top: ${props => props.mt ? props.mt : '10px'};
  margin-left: ${props => props.ml ? props.ml : '10px'};
  margin-right: ${props => props.mr ? props.mr : '10px'};
`;

const ButtonComponent = ({
  children,
  alternative,
  width,
  mr,
  ml,
  mt,
  buttonPress,
  isLoadingRequest,
}) => {

  return (
    <CustomButton style={{
      shadowColor: '#171717',
      shadowOffset: { width: -2, height: 4 },
      shadowOpacity: 0.2,
      shadowRadius: 3,
    }} width={width} mt={mt} mr={mr} ml={ml} alternative={alternative}
                  underlayColor={alternative ? 'transparent' : '#7B04BB'}
                  activeOpacity={0.6} onPress={() => {
      if (!isLoadingRequest) {
        buttonPress();
      }
    }}>
      <View>
        {!isLoadingRequest ?
          <TextComponent fontWeight={500} fontSize={13} color={alternative
            ? '#7B04BB'
            : 'white'}>{children}</TextComponent>
          : <ActivityIndicator color={alternative ? '#7B04BB' : 'white'}/>}
      </View>
    </CustomButton>
  );
};

export default ButtonComponent;