import React from 'react';
import styled from 'styled-components/native';
import dateFormat from 'dateformat';
import { View } from 'react-native';
import { LinearGradient } from 'expo-linear-gradient';
import { ImageBackground } from 'react-native';
import ButtonComponent from './ButtonComponent';
import { Feather } from '@expo/vector-icons';
import { FontAwesome } from '@expo/vector-icons';
import TransparentButtonComponent from './TransparentButtonComponent';
import axios from 'axios';
import { fetchHolidays } from '../store/slices/holidaysSlice';
import { useDispatch } from 'react-redux';

const HolidayTitle = styled.Text`
  font-size: 16px;
  font-weight: bold;
  color: white;
  line-height: 16px;
`;

const HolidayDate = styled.Text`
  font-size: 15px;
  line-height: 18px;
  color: white;
`;

const HolidayContainer = styled.View`
  border-radius: 15px;
  max-height: 250px;
  margin: 15px;

`;
const HolidayCard = styled.View`
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: space-between;
  padding: 15px;
`;
const HolidayUsers = styled.View`
  width: 30%;
  //background-color: white;
  border: 1px solid #FFFFFF;
  border-radius: 16px;
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 7px;
`;
const TextUsers = styled.Text`
  color: white;
  font-weight: bold;
  font-size: 10px;
`;
const FavoriteIcon = styled.View`
  background-color: #0C0012;
  backdrop-filter: blur(20px);
  width: 30px;
  height: 30px;
  border-radius: 15px;
  position: absolute;
  top: 15px;
  right: 15px;
  display: flex;
  justify-content: center;
  align-items: center;
`;

const HolidayComponent = ({
  item,
  title,
  date,
  base64,
  users,
  buttonFavoriteAdd,
  buttonFavoriteLeave,
  favorite,
  user,
}) => {

  const dispatch = useDispatch();
  const [isLoadingRequest, setIsLoadingRequest] = React.useState(false);
  const [isLoadingTransparent, setIsLoadingTransparent] = React.useState(false);

  const enjoyUser = (party) => {
    setIsLoadingRequest(true);
    axios.put(`${process.env.API}/holidays`, {
      operation: 'add',
      holidayId: party._id,
      userId: user._id,
      firstname: user.firstname,
      secondname: user.secondname,
      userAvatar: user.userAvatar,
      isMan: user.isMan,
      notificationToken: user.notificationToken,
    }).then(async () => {
      await dispatch(fetchHolidays());
      setIsLoadingRequest(false);
    }).catch((e) => {
      console.log(e);
      setIsLoadingRequest(false);
    });
  };

  const addFavorite = (party) => {
    setIsLoadingTransparent(true);
    axios.put(`${process.env.API}/holidays`, {
      operation: 'addFavorite',
      holidayId: party._id,
      userId: user._id,
    }).then(async () => {
      await dispatch(fetchHolidays());
      setIsLoadingTransparent(false);
    }).catch((e) => {
      console.log(e);
      setIsLoadingTransparent(false);
    });
  };

  const leaveFavorite = (party) => {
    setIsLoadingTransparent(true);
    axios.put(`${process.env.API}/holidays`, {
      operation: 'leaveFavorite',
      holidayId: party._id,
      userId: user._id,
    }).then(async () => {
      await dispatch(fetchHolidays());
      setIsLoadingTransparent(false);
    }).catch((e) => {
      console.log(e);
      setIsLoadingTransparent(false);
    });
  };

  const leaveUser = (party) => {
    setIsLoadingRequest(true);
    axios.put(`${process.env.API}/holidays`, {
      operation: 'delete',
      holidayId: party._id,
      userId: user._id,
    }).then(async () => {
      await dispatch(fetchHolidays());
      setIsLoadingRequest(false);
    }).catch((e) => {
      console.log(e);
      setIsLoadingRequest(false);
    });
  };

  return (
    <HolidayContainer>
      <ImageBackground style={{
        width: '100%',
        borderRadius: 16,
        overflow: 'hidden',
        height: 137,
      }} source={{ uri: `data:image/jpeg;base64,${base64}` }}>
        <LinearGradient start={[0.5, 0.5]} end={[0.5, 0.5]}
                        style={{ width: '100%', height: '100%' }}
                        colors={['rgba(0, 0, 0, 0.6)', 'rgba(0, 0, 0, 0.6)']}>
          <FavoriteIcon>
            {favorite.filter(x => x === user._id).length ?
              <FontAwesome name="star" size={24} color="#ED8B16"/> :
              <Feather name="star" size={24} color="#ED8B16"/>
            }
          </FavoriteIcon>
          <HolidayCard>
            <HolidayTitle>{title}</HolidayTitle>
            <View>
              <HolidayDate>{dateFormat(date, 'mmmm')}</HolidayDate>
              <HolidayDate>{dateFormat(date, 'dS,yyyy')}</HolidayDate>
            </View>
            <HolidayUsers><TextUsers>{users.length} учасників</TextUsers></HolidayUsers>
          </HolidayCard>
        </LinearGradient>
      </ImageBackground>

      <View style={{ flexDirection: 'row', justifyContent: 'space-between' }}>
        <TransparentButtonComponent ml={'-20px'} mr={'0px'} width={'47%'}
                                    isLoadingTransparent={isLoadingTransparent}
                                    buttonPress={() => {
                                      if (favorite.filter(
                                        x => x === user._id).length) {
                                        leaveFavorite(item);
                                      } else {
                                        addFavorite(item);
                                      }
                                    }}
        >
          {favorite.filter(x => x === user._id).length ? 'Не цікаве' : 'Цікаве'}
        </TransparentButtonComponent>
        <ButtonComponent
          buttonPress={() => {
            if (users.filter(x => x.userId === user._id).length) {
              leaveUser(item);
            } else {
              enjoyUser(item);
            }
          }}
          isLoadingRequest={isLoadingRequest}
          ml={'0px'} mr={'0px'} width={'47%'}
          alternative={users.filter(
            x => x.userId === user._id).length}>{users.filter(
          x => x.userId === user._id).length
          ? 'Покинути'
          : 'Приєднатись'}</ButtonComponent>
      </View>
    </HolidayContainer>
  );
};

export default HolidayComponent;