import React from 'react';
import styled from 'styled-components/native';
import {
  Image,
  Keyboard,
  TouchableHighlight,
  View,
} from 'react-native';
import { useAuthScreen } from './useAuthScreen';
import InputComponent from '../../../components/InputComponent';
import TextComponent from '../../../components/TextComponent';
import ButtonComponent from '../../../components/ButtonComponent';
import SnackComponent from '../../../components/SnackComponent';

const AuthMainContainer = styled.View`
  flex: 1;
  padding: 15px;
  background-color: white;
`;

const AuthSecondHalfContainer = styled.TouchableHighlight`
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
`;

const AuthScreen = ({ navigation }) => {
  const {
    models: {
      visible,
      isScrollTop,
      password,
      error,
      email,
      setEmail,
      setPassword,
      setError,
      setIsScrollTop,
      isLoadingRequest,
    },
    commands: { onDismissSnackBar, inputSelect, sendReq },
  } = useAuthScreen({ navigation });

  return (
    <AuthMainContainer>
      <SnackComponent error={error} visible={visible}
                      onDismissSnackBar={onDismissSnackBar}/>

      <AuthSecondHalfContainer underlayColor="transparent" activeOpacity={1}
                               isScrollTop={isScrollTop}
                               onPress={() => {
                                 setIsScrollTop(false);
                                 Keyboard.dismiss();
                               }}>
        <View style={{
          display: 'flex',
          width: '100%',
          alignItems: 'center',
          justifyContent: 'center',
        }}>
          <Image style={{ height: 60, width: 100, marginTop: 10 }}
                 source={require('../../../../assets/groupbwt/bwtAuth.png')}/>
          <TextComponent fontSize={19} marginTop={15} fontWeight={400}> Прийміть
            участь у святкуванні.</TextComponent>
          <TextComponent fontSize={20} fontWeight={600}>Для цього -
            авторизуйтесь. </TextComponent>

          <Image
            style={{ height: 260, width: 140, marginTop: 20, borderRadius: 10 }}
            source={require('../../../../assets/groupbwt/santa.png')}/>

          <InputComponent value={email}
                          onChangeText={(email) => setEmail(email)}
                          inputPass={() => {setIsScrollTop(false);}}
                          inputSelect={inputSelect} marginTop="20px"
                          placeholder="Ваш e-mail"/>

          <InputComponent value={password}
                          onChangeText={(password) => setPassword(password)}
                          secureTextEntry={true}
                          inputPass={() => {setIsScrollTop(false);}}
                          inputSelect={inputSelect} marginTop="10px"
                          placeholder="Ваш пароль"/>

          <ButtonComponent isLoadingRequest={isLoadingRequest} width={'50%'}
                           mt={'20px'} buttonPress={() => {
            setError('');
            sendReq();
          }}>Вхід</ButtonComponent>
          <TouchableHighlight style={{ marginTop: 20 }}
                              underlayColor="transparent" activeOpacity={1}
                              onPress={() => {
                                navigation.navigate('Registration');
                              }}>
            <TextComponent fontWeight={400} fontSize={17}
                           textDecoration=" #ACACAC underline"
                           color="#ACACAC">Зареєструватися</TextComponent>
          </TouchableHighlight>

        </View>
      </AuthSecondHalfContainer>

    </AuthMainContainer>
  );
};

export default AuthScreen;