import { useDispatch } from 'react-redux';
import React from 'react';
import axios from 'axios';
import { fetchHolidays, saveUser } from '../../../store/slices/holidaysSlice';
import { AsyncStorage, Keyboard } from 'react-native';

export function useAuthScreen ({ navigation }) {
  const [isScrollTop, setIsScrollTop] = React.useState(false);
  const [email, setEmail] = React.useState('');
  const [password, setPassword] = React.useState('');
  const [error, setError] = React.useState('');
  const [visible, setVisible] = React.useState(false);
  const [isLoadingRequest, setIsLoadingRequest] = React.useState(false);

  const dispatch = useDispatch();

  const onToggleSnackBar = () => setVisible(!visible);
  const onDismissSnackBar = () => setVisible(false);

  const inputSelect = () => {
    setIsScrollTop(true);
  };

  const sendReq = async () => {
    setIsLoadingRequest(true);
    setIsScrollTop(false);
    const body = {
      email,
      password,
    };
    axios.post(`${process.env.API}/login`, body, {
      headers: {
        'Content-Type': 'application/json',
      },
    }).then(async function (response) {
      const user = response.data.message;
      user.token = `userToken=${response.data.token}`;
      dispatch(saveUser(user));
      try {
        await AsyncStorage.setItem(
          'user',
          JSON.stringify(user),
        );
      } catch (error) {
        console.log(error);
      }
      dispatch(fetchHolidays());
      setIsLoadingRequest(false);
      navigation.navigate('Main', { screen: 'Свята' });
    }).catch(function (error) {
      setError('Невірний e-mail або пароль');
      setIsLoadingRequest(false);
      onToggleSnackBar();
    });
    Keyboard.dismiss();
  };

  return {
    models: {
      visible,
      isScrollTop,
      password,
      error,
      email,
      setEmail,
      setPassword,
      setError,
      setVisible,
      setIsScrollTop,
      isLoadingRequest,
    },
    commands: {
      onToggleSnackBar,
      onDismissSnackBar,
      inputSelect,
      sendReq,
    },
  };
}