import React from 'react';
import styled from 'styled-components/native';
import {
  Image,
  Keyboard, TouchableHighlight,
  View,
} from 'react-native';
import InputComponent from '../../../components/InputComponent';
import TextComponent from '../../../components/TextComponent';
import ButtonComponent from '../../../components/ButtonComponent';
import SnackComponent from '../../../components/SnackComponent';
import { useRegisterScreen } from './useRegisterScreen';
import Checkbox from 'expo-checkbox';

const AuthMainContainer = styled.View`
  flex: 1;
  padding: 15px;
  background-color: white;
`;

const AuthSecondHalfContainer = styled.TouchableHighlight`
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
`;

const CheckboxContainer = styled.View`
  width: 80%;
  margin-top: 10px;
`;

const CheckboxRow = styled.View`
  margin-top: 5px;
  flex-direction: row;
  width: 100%;
  display: flex;
  justify-content: space-between;

  height: ${props => props.multiline ? '120px' : '50px'};
  background-color: #F3E4FF;
  border-style: solid;
  border-width: 1px;
  border-color: #D9BFEF;
  border-radius: 10px;
  padding: 10px 20px;
`;
const OneCheck = styled.View`
  display: flex;
  justify-content: center;
  align-items: center;
  flex-direction: row;
`;

const RegisterScreen = ({ navigation }) => {

  const {
    models: {
      isScrollTop,
      email,
      password,
      repeatPassword,
      firstName,
      secondName,
      nextScreen,
      error,
      visible,
      setIsScrollTop,
      setNextScreen,
      setError,
      setEmail,
      setPassword,
      setRepeatPassword,
      setFirstName,
      setSecondName,
      isMan,
      setIsMan,
      isLoadingRequest,
    },
    commands: { onDismissSnackBar, inputSelect, sendRegisterRequest },
  } = useRegisterScreen({ navigation });

  return (
    <AuthMainContainer>
      <SnackComponent error={error} visible={visible}
                      onDismissSnackBar={onDismissSnackBar}/>
      {!nextScreen &&
        <AuthSecondHalfContainer underlayColor="transparent" activeOpacity={1}
                                 isScrollTop={isScrollTop}
                                 onPress={() => {
                                   setIsScrollTop(false);
                                   Keyboard.dismiss();
                                 }}>
          <View style={{
            display: 'flex',
            width: '100%',
            alignItems: 'center',
            justifyContent: 'center',
          }}>
            <Image style={{ height: 60, width: 100, marginTop: 10 }}
                   source={require(
                     '../../../../assets/groupbwt/bwtAuth.png')}/>
            <TextComponent fontSize={'20px'} marginTop={15}
                           color={'#0C0012'}>Реєстрація</TextComponent>
            <TextComponent marginTop={10} fontSize={18}>Хочете створити новий
              акаунт?</TextComponent>

            <InputComponent value={email}
                            onChangeText={(email) => setEmail(email)}
                            inputPass={() => {setIsScrollTop(false);}}
                            inputSelect={inputSelect} marginTop="10px"
                            placeholder="Ваш e-mail"/>

            <InputComponent value={password}
                            onChangeText={(password) => setPassword(password)}
                            secureTextEntry={true}
                            inputPass={() => {setIsScrollTop(false);}}
                            inputSelect={inputSelect} marginTop="10px"
                            placeholder="Ваш пароль"/>

            <InputComponent value={repeatPassword}
                            onChangeText={(repeatPassword) => setRepeatPassword(
                              repeatPassword)}
                            secureTextEntry={true}
                            inputPass={() => {setIsScrollTop(false);}}
                            inputSelect={inputSelect} marginTop="10px"
                            placeholder="Повторіть пароль"/>
            <ButtonComponent mt={20} width={'50%'} buttonPress={() => {
              setNextScreen(true);
              setIsScrollTop(false);
            }}>Далі</ButtonComponent>
            <TouchableHighlight style={{ marginTop: 20 }}
                                underlayColor="transparent" activeOpacity={1}
                                onPress={() => {
                                  navigation.navigate('Authorization');
                                }}>
              <TextComponent fontWeight={400} fontSize={17}
                             textDecoration=" #ACACAC underline"
                             color="#ACACAC">Вже є аккаунт?</TextComponent>
            </TouchableHighlight>
          </View>
        </AuthSecondHalfContainer>}

      {nextScreen &&
        <AuthSecondHalfContainer underlayColor="transparent" activeOpacity={1}
                                 isScrollTop={isScrollTop}
                                 onPress={() => {
                                   setIsScrollTop(false);
                                   Keyboard.dismiss();
                                 }}>
          <View style={{
            display: 'flex',
            width: '100%',
            alignItems: 'center',
            justifyContent: 'center',
          }}>
            <Image style={{ height: 60, width: 100, marginTop: 10 }}
                   source={require(
                     '../../../../assets/groupbwt/bwtAuth.png')}/>
            <TextComponent fontSize={'20px'} marginTop={15}
                           color={'#0C0012'}>Реєстрація</TextComponent>
            <TextComponent marginTop={10} fontSize={18}>Хочете створити новий
              акаунт?</TextComponent>

            <CheckboxContainer>
              <TextComponent fontSize={'18px'}>Оберіть стать:</TextComponent>
              <CheckboxRow>
                <OneCheck>
                  <TextComponent fontSize={'16px'}
                                 pr={'5px'}>Чоловіча</TextComponent>
                  <Checkbox color={'#7913af'} value={isMan}
                            onValueChange={() => {setIsMan(true);}}/>
                </OneCheck>
                <OneCheck>
                  <TextComponent fontSize={'16px'}
                                 pr={'5px'}>Жіноча</TextComponent>
                  <Checkbox color={'#7913af'} value={!isMan}
                            onValueChange={() => {setIsMan(false);}}/>
                </OneCheck>
              </CheckboxRow>
            </CheckboxContainer>

            <InputComponent value={firstName}
                            onChangeText={(firstName) => setFirstName(
                              firstName)}
                            inputPass={() => {setIsScrollTop(false);}}
                            inputSelect={inputSelect} marginTop="10px"
                            placeholder="Ваше ім'я"/>

            <InputComponent value={secondName}
                            onChangeText={(secondName) => setSecondName(
                              secondName)}
                            inputPass={() => {setIsScrollTop(false);}}
                            inputSelect={inputSelect} marginTop="10px"
                            placeholder="Ваше прізвище"/>
            <ButtonComponent mt={20} width={'50%'}
                             isLoadingRequest={isLoadingRequest}
                             buttonPress={() => {
                               sendRegisterRequest();
                               setError('');
                               setIsScrollTop(false);
                             }}>Далі</ButtonComponent>

            <ButtonComponent width={'50%'} alternative buttonPress={() => {
              setNextScreen(false);
              setIsScrollTop(false);
            }}>Назад</ButtonComponent>
          </View>
        </AuthSecondHalfContainer>}
    </AuthMainContainer>
  );
};

export default RegisterScreen;