import React from 'react';
import { useDispatch } from 'react-redux';
import {
  registerForPushNotificationsAsync,
} from '../../../notifications/useNotification';
import axios from 'axios';
import { fetchHolidays, saveUser } from '../../../store/slices/holidaysSlice';
import { AsyncStorage, Keyboard } from 'react-native';

export function useRegisterScreen ({ navigation }) {
  const [isScrollTop, setIsScrollTop] = React.useState(false);
  const [isMan, setIsMan] = React.useState(true);
  const [email, setEmail] = React.useState('');
  const [password, setPassword] = React.useState('');
  const [repeatPassword, setRepeatPassword] = React.useState('');
  const [firstName, setFirstName] = React.useState('');
  const [secondName, setSecondName] = React.useState('');
  const [nextScreen, setNextScreen] = React.useState(false);
  const [error, setError] = React.useState('');
  const [visible, setVisible] = React.useState(false);
  const [isLoadingRequest, setIsLoadingRequest] = React.useState(false);

  const dispatch = useDispatch();

  const onToggleSnackBar = () => setVisible(!visible);
  const onDismissSnackBar = () => setVisible(false);

  const inputSelect = () => {
    setIsScrollTop(true);
  };

  const sendRegisterRequest = async () => {
    if (!password.length) {
      setError('Заповніть поле з паролем');
      onToggleSnackBar();
    } else if (password !== repeatPassword) {
      setError('Паролі не співпадають');
      onToggleSnackBar();
    } else {
      setIsLoadingRequest(true);
      let notificationToken;
      notificationToken = await registerForPushNotificationsAsync();
      setIsScrollTop(false);
      const body = {
        email,
        password,
        firstname: firstName,
        secondname: secondName,
        isMan,
        notificationToken,
      };

      axios.post(`${process.env.API}/registration`, body, {
        headers: {
          'Content-Type': 'application/json',
        },
      }).then(async function (response) {
        if (response.data.status === 403) {
          setError('Емейл вже зареєстрований');
          setIsLoadingRequest(false);
          onToggleSnackBar();
        } else {
          const user = response.data.message;
          user.token = `userToken=${response.data.token}`;
          dispatch(saveUser(user));
          try {
            await AsyncStorage.setItem(
              'user',
              JSON.stringify(user),
            );
          } catch (error) {
            console.log(error);
          }
          dispatch(fetchHolidays());
          setIsLoadingRequest(false);
          navigation.navigate('Main', { screen: 'Свята' });
        }
      }).catch((e) => {
        setError('Емейл вже зареєстрований');
        setIsLoadingRequest(false);
        onToggleSnackBar();
      });
      Keyboard.dismiss();
    }

  };
  return {
    models: {
      isLoadingRequest,
      isScrollTop,
      isMan,
      email,
      password,
      repeatPassword,
      firstName,
      secondName,
      nextScreen,
      error,
      visible,
      setVisible,
      setIsMan,
      setIsScrollTop,
      setNextScreen,
      setError,
      setEmail,
      setPassword,
      setRepeatPassword,
      setFirstName,
      setSecondName,
    },
    commands: {
      onToggleSnackBar,
      onDismissSnackBar,
      inputSelect,
      sendRegisterRequest,
    },
  };
}