import React from 'react';
import styled from 'styled-components/native';
import axios from 'axios';
import TextComponent from '../../../components/TextComponent';
import { Image, TouchableHighlight, View } from 'react-native';
import { useAssistantScreen } from './useAssistantScreen';
import { AntDesign } from '@expo/vector-icons';

const AssistantContainer = styled.View`
  flex: 1;
  background-color: white;
`;
const AssistantUserContainer = styled.View`
  display: flex;
  justify-content: center;
  align-items: center;
  margin-top: 10px;
`;

const AssistantScreen = ({ navigation }) => {

  const {
    models: {
      singleHoliday,
      user,
      assistant,
      setAssistant,
      self,
      setSelf,
      cooperative,
      setCooperative,
    },
  } = useAssistantScreen();

  React.useEffect(() => {
    if (singleHoliday.mode === 'default') {
      console.log('work');
      let sendId = [];
      singleHoliday.startUsers.forEach((el, index) => {
        if (el[0].userId === user._id) {
          sendId.push(el[1].userId);
        } else if (el[1].userId === user._id) {
          sendId.push(el[0].userId);
        }
      });
      axios.put(`${process.env.API}/registration`, sendId).
        then((resp) => {
          setAssistant(resp.data);
        });
    } else if (singleHoliday.mode === 'manToWomen') {
      if (user.isMan === false) {
        setSelf(true);
      } else {
        let arrayMain = [];
        singleHoliday.startUsers.forEach((x, index) => {
          if (x.some(el => el.userId === user._id)) {
            arrayMain = [...singleHoliday.startUsers[index]];
          }
        });
        setCooperative(arrayMain.filter(x => x.isMan && x.userId !== user._id));
        let findById = arrayMain.filter(x => !x.isMan);
        findById = findById.map(x => x.userId);
        axios.put(`${process.env.API}/registration`, findById).
          then((resp) => {
            setAssistant(resp.data);
          });
      }
    } else if (singleHoliday.mode === 'womenToMan') {
      if (user.isMan === true) {
        setSelf(true);
      } else {
        let arrayMain = [];
        singleHoliday.startUsers.forEach((x, index) => {
          if (x.some(el => el.userId === user._id)) {
            arrayMain = [...singleHoliday.startUsers[index]];
          }
        });
        setCooperative(
          arrayMain.filter(x => !x.isMan && x.userId !== user._id));
        let findById = arrayMain.filter(x => x.isMan);
        findById = findById.map(x => x.userId);
        axios.put(`${process.env.API}/registration`, findById).
          then((resp) => {
            setAssistant(resp.data);
          });
      }
    }
  }, []);

  return (
    <AssistantContainer>
      {self &&
        <TextComponent fontSize={'18px'} pl={'5%'} pr={'5%'} marginTop={'10px'}>
          Цього разу вам нікому подарунок дарити не треба. Просто чекайте на
          свій
          подарунок.
        </TextComponent>}
      {cooperative.length ? (
        <AssistantUserContainer>
          <TextComponent color={'#0C0012'} fontSize={20}>Скооперуйтеся з
            :</TextComponent>
          {cooperative.map(coop => (
            <View style={{
              flexDirection: 'row',
              width: '90%',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'space-between',
            }}>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                alignItems: 'center',
              }}>
                <Image style={{ height: 75, width: 75 }}
                       source={{ uri: coop.userAvatar }}/>
                <TextComponent color={'#0C0012'} fontSize={18}
                               marginTop={10}>{coop.firstname} {coop.secondname}</TextComponent>
              </View>
            </View>
          ))}
        </AssistantUserContainer>
      ) : null}

      {assistant.length ? (<View style={{ height: '100%' }}>
        <AssistantUserContainer>
          <TextComponent color={'#0C0012'} fontSize={20}>Оберіть подарунок
            для:</TextComponent>
          {assistant.map(user => (
            <View style={{
              flexDirection: 'row',
              width: '90%',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'space-between',
            }}>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                alignItems: 'center',
              }}>
                <Image style={{ height: 75, width: 75 }}
                       source={{ uri: user.userAvatar }}/>
                <TextComponent color={'#0C0012'} fontSize={18}
                               marginTop={10}>{user.firstname} {user.secondname}</TextComponent>
              </View>
              <TouchableHighlight underlayColor={'transparent'}
                                  activeOpacity={1} onPress={() => {
                navigation.navigate('YourAssistantWish', user.wishList);
              }}>
                <AntDesign style={{ float: 'right' }} name="gift" size={30}
                           color="#7B04BB"/>
              </TouchableHighlight>
            </View>
          ))}
        </AssistantUserContainer>
      </View>) : null}

      {!assistant.length && !cooperative.length && !self && (
        <View style={{ flex: 1, padding: 15 }}>
          <TextComponent fontSize={'18px'}>Нажаль свято вже почалось. Ви можете
            звернутися до адміна, що би вирішити цю проблему.</TextComponent>
        </View>
      )}
    </AssistantContainer>
  );
};

export default AssistantScreen;