import React from 'react';
import styled from 'styled-components/native';
import {
  Image,
  Keyboard,
  TouchableHighlight,
  View,
  StyleSheet,
  Platform,
} from 'react-native';
import RNPickerSelect from 'react-native-picker-select';
import InputComponent from '../../../components/InputComponent';
import SnackComponent from '../../../components/SnackComponent';
import CalendarPicker from 'react-native-calendar-picker';
import NumericInput from 'react-native-numeric-input';
import TextComponent from '../../../components/TextComponent';
import { useCreateHolidayScreen } from './useCreateHolidayScreen';
import ButtonComponent from '../../../components/ButtonComponent';
import Checkbox from 'expo-checkbox';
import { MaterialIcons } from '@expo/vector-icons';

const HolidayContainer = styled.View`
  flex: 1;
  align-items: center;
`;

const MaxPrice = styled.View`
  flex-direction: row;
  display: flex;
  width: 80%;
  align-items: center;
  justify-content: space-between;
  height: 60px;
  background-color: transparent;
`;

const CreateHolidayScreen = ({ navigation }) => {
  const {
    models: {
      title,
      setTitle,
      description,
      setDescription,
      setDate,
      maxPrice,
      setMaxPrice,
      base64,
      visible,
      error,
      secondPage,
      setSecondPage,
      setMode,
      mode,
      hide,
      setHide,
    },
    commands: { requiredFields, openCamera, onDismissSnackBar },
  } = useCreateHolidayScreen({ navigation });

  return (
    <View style={{ flex: 1, backgroundColor: 'white' }}>
      {secondPage === 'first' &&
        <TouchableHighlight underlayColor="transparent" activeOpacity={1}
                            style={{ flex: 1 }}
                            onPress={() => {
                              Keyboard.dismiss();
                              setHide(false);
                            }}>
          <HolidayContainer>
            {!hide &&
              <Image style={{ width: '80%', marginTop: 25, borderRadius: 10 }}
                     source={require(
                       '../../../../assets/groupbwt/createHoliday.jpg')}/>}
            <SnackComponent error={error} visible={visible}
                            onDismissSnackBar={onDismissSnackBar}/>
            <InputComponent value={title}
                            onChangeText={(title) => {setTitle(title);}}
                            placeholder="Введіть назву свята"
                            inputSelect={() => {
                              setHide(true);
                              console.log('select');
                            }}
                            inputPass={() => {Keyboard.dismiss();}}
                            marginTop={20}/>
            <InputComponent multiline
                            value={description}
                            onChangeText={(description) => {
                              setDescription(description);
                            }}
                            placeholder="Введіть опис свята"
                            inputSelect={() => {
                              setHide(true);
                              console.log('select');
                            }}
                            inputPass={() => {Keyboard.dismiss();}}
                            marginTop={15}/>
            <MaxPrice style={{
              marginTop: 15,
              shadowColor: '#171717',
              shadowOffset: { width: 0, height: 3 },
              shadowOpacity: 0.2,
              shadowRadius: 2,
            }}>
              <TextComponent fontSize={16}>Ціна до:</TextComponent>
              <NumericInput iconStyle={{
                backgroundColor: '#F3E4FF',
                borderRadius: 20,
                padding: 7,
                fontSize: 20,
                textAlign: 'center',
              }} borderColor="transparent" value={maxPrice}
                            leftButtonBackgroundColor="transparent"
                            rightButtonBackgroundColor="transparent" rounded
                            onChange={value => setMaxPrice(value)}/>
            </MaxPrice>
            <View style={{
              position: 'absolute',
              bottom: 20,
              width: '100%',
              display: 'flex',
              alignItems: 'center',
            }}>
              <ButtonComponent mt={'30px'} width={'50%'} buttonPress={() => {
                setSecondPage('second');
              }}>Далі</ButtonComponent>
            </View>
          </HolidayContainer>
        </TouchableHighlight>}

      {secondPage === 'second' &&
        <TouchableHighlight underlayColor="transparent" activeOpacity={1}
                            style={{ flex: 1 }}
                            onPress={() => {Keyboard.dismiss();}}>
          <HolidayContainer>
            <SnackComponent error={error} visible={visible}
                            onDismissSnackBar={onDismissSnackBar}/>
            <View style={{
              width: '100%',
              paddingLeft: 15,
              paddingRight: 15,
              paddingTop: 5,
              paddingBottom: 10,
            }}><TextComponent fontSize={'17px'}>Оберіть дату
              проведення:</TextComponent></View>
            <CalendarPicker
              weekdays={['СБ', 'ПН', 'ВТ', 'СР', 'ЧТ', 'ПТ', 'НД']}
              months={[
                'Січень',
                'Лютий',
                'Березень',
                'Квітень',
                'Травень',
                'Червень',
                'Липень',
                'Серпень',
                'Вересень',
                'Жовтень',
                'Листопад',
                'Грудень']}
              yearTitleStyle={{ color: '#7B04BB' }}
              monthTitleStyle={{ color: '#7B04BB' }}
              previousComponent={<MaterialIcons name="navigate-before" size={24}
                                                color="#7B04BB"/>}
              nextComponent={<MaterialIcons name="navigate-next" size={24}
                                            color="#7B04BB"/>}
              onDateChange={(day) => {setDate(day);}}
              todayBackgroundColor={'#FFCCFF'}
              todayTextStyle={{ color: 'black' }}
              selectedDayTextColor="#ffffff"
              selectedDayStyle={{ backgroundColor: '#9721D8' }}/>
            <View style={{
              position: 'absolute',
              bottom: 20,
              left: 0,
              width: '100%',
            }}>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                justifyContent: 'space-between',
              }}>
                <ButtonComponent buttonPress={() => {setSecondPage('first');}}
                                 alternative
                                 width={'44%'}>Назад</ButtonComponent>
                <ButtonComponent width={'44%'} buttonPress={() => {
                  setSecondPage('third');
                }}>Далі</ButtonComponent>
              </View>
            </View>
          </HolidayContainer>
        </TouchableHighlight>}

      {secondPage === 'third' &&
        <TouchableHighlight underlayColor="transparent" activeOpacity={1}
                            style={{ flex: 1 }}
                            onPress={() => {Keyboard.dismiss();}}>
          <HolidayContainer>
            <SnackComponent error={error} visible={visible}
                            onDismissSnackBar={onDismissSnackBar}/>
            <View style={{
              width: '100%',
              paddingLeft: 15,
              paddingRight: 15,
              paddingTop: 0,
              paddingBottom: 10,
              flexDirection: 'row',
              display: 'flex',
              alignItems: 'center',
            }}>
              <TextComponent fontSize={'17px'}>Оберіть фото:</TextComponent>
              <ButtonComponent ml={'30px'} buttonPress={() => {openCamera();}}
                               width={'40%'}>Обрати</ButtonComponent>
            </View>
            <Image source={{ uri: `data:image/jpeg;base64,${base64}` }} style={{
              height: 300,
              width: 300,
              borderWidth: 1,
              borderColor: '#7B04BB',
              borderRadius: 15,
            }}/>

            <View style={{
              width: '100%',
              paddingLeft: 15,
              paddingRight: 15,
              paddingTop: 10,
              paddingBottom: 10,
            }}><TextComponent fontSize={'17px'}>Оберіть режим
              проведення:</TextComponent></View>

            {Platform.OS === 'ios' ? <RNPickerSelect
              style={{ ...pickerSelectStyles }}
              onValueChange={(value) => setMode(value)}
              items={[
                { label: 'Звичайний', value: 'default' },
                { label: 'М ---> Ж', value: 'manToWomen' },
                { label: 'Ж ---> М', value: 'womenToMan' },
              ]}
            /> : <View
              style={{ width: '100%', paddingLeft: 15, paddingRight: 15 }}>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                alignItems: 'center',
                paddingVertical: 5,
              }}>
                <Checkbox color={'#7B04BB'}
                          onValueChange={() => {setMode('default');}}
                          value={mode === 'default'}></Checkbox>
                <TouchableHighlight underlayColor="transparent"
                                    activeOpacity={1}
                                    onPress={() => {setMode('default');}}>
                  <TextComponent fontSize={'16px'} pl={'10px'}>Звичайний
                    режим</TextComponent>
                </TouchableHighlight>
              </View>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                alignItems: 'center',
                paddingVertical: 5,
              }}>
                <Checkbox color={'#7B04BB'}
                          onValueChange={() => {setMode('manToWomen');}}
                          value={mode === 'manToWomen'}></Checkbox>
                <TouchableHighlight underlayColor="transparent"
                                    activeOpacity={1}
                                    onPress={() => {setMode('manToWomen');}}>
                  <TextComponent fontSize={'16px'} pl={'10px'}>Чоловіки до
                    жінок</TextComponent>
                </TouchableHighlight>
              </View>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                alignItems: 'center',
                paddingVertical: 5,
              }}>
                <Checkbox color={'#7B04BB'}
                          onValueChange={() => {setMode('womenToMan');}}
                          value={mode === 'womenToMan'}></Checkbox>
                <TouchableHighlight underlayColor="transparent"
                                    activeOpacity={1}
                                    onPress={() => {setMode('womenToMan');}}>
                  <TextComponent fontSize={'16px'} pl={'10px'}>Жінки до
                    чоловіків</TextComponent>
                </TouchableHighlight>
              </View>
            </View>}


            <View style={{
              position: 'absolute',
              bottom: 20,
              left: 0,
              width: '100%',
            }}>
              <View style={{
                flexDirection: 'row',
                display: 'flex',
                justifyContent: 'space-between',
              }}>
                <ButtonComponent buttonPress={() => {setSecondPage('second');}}
                                 alternative
                                 width={'44%'}>Назад</ButtonComponent>
                <ButtonComponent buttonPress={() => {requiredFields();}}
                                 width={'44%'}>Створити</ButtonComponent>
              </View>
            </View>
          </HolidayContainer>
        </TouchableHighlight>}
    </View>
  );
};

const pickerSelectStyles = StyleSheet.create({
  inputIOS: {
    width: '80%',
    alignSelf: 'center',
    height: 50,
    backgroundColor: 'transparent',
    borderStyle: 'solid',
    borderWidth: 1,
    borderColor: '#7B04BB',
    borderRadius: 10,
    paddingHorizontal: 20,
    paddingVertical: 10,
    color: '#000000',
    fontSize: 16,
    fontWeight: '500',
  },
  inputAndroid: {
    width: '80%',
    alignSelf: 'center',
    height: 50,
    backgroundColor: '#F8FFEC',
    borderStyle: 'solid',
    borderWidth: 1,
    borderColor: '#6DAD04',
    borderRadius: 10,
    paddingHorizontal: 20,
    paddingVertical: 10,
    color: '#000000',
    fontSize: 16,
    fontWeight: '500',
  },
});

export default CreateHolidayScreen;