import { useDispatch, useSelector } from 'react-redux';
import React from 'react';
import axios from 'axios';
import { fetchHolidays } from '../../../store/slices/holidaysSlice';
import * as ImagePicker from 'expo-image-picker';
import { manipulateAsync } from 'expo-image-manipulator';

export function useCreateHolidayScreen ({ navigation }) {

  const dispatch = useDispatch();
  const user = useSelector(state => state.holidaySlice.user);
  const [title, setTitle] = React.useState('');
  const [description, setDescription] = React.useState('');
  const [date, setDate] = React.useState('');
  const [users, setUsers] = React.useState([]);
  const [maxPrice, setMaxPrice] = React.useState(200);
  const [base64, setBase64] = React.useState(null);
  const [visible, setVisible] = React.useState(false);
  const [error, setError] = React.useState('');
  const [imageUri, setImageUri] = React.useState(null);
  const [secondPage, setSecondPage] = React.useState('first');
  const [mode, setMode] = React.useState();
  const [hide, setHide] = React.useState(false);

  const onToggleSnackBar = () => setVisible(!visible);

  const onDismissSnackBar = () => setVisible(false);

  const requiredFields = () => {
    console.log('work');
    const rightDate = new Date(date);
    if (title.length && description.length && mode && base64 !== null &&
      rightDate instanceof Date && !isNaN(rightDate.valueOf())) {

      const body = {
        operation: 'create',
        isStarted: false,
        title,
        description,
        date: rightDate,
        maxPrice,
        mode,
        base64,
        users: [
          {
            userId: user._id,
            firstname: user.firstname,
            secondname: user.secondname,
            isMan: user.isMan,
            userAvatar: user.userAvatar,
            notificationToken: user.notificationToken,
          }],
        startUsers: [],
        favorite: [],
      };

      axios.post(`${process.env.API}/holidays`, body).
        then(resp => console.log(resp)).
        then(() => {
          dispatch(fetchHolidays());
          navigation.navigate('Main');
        }).
        catch((e) => {console.log(e);});
    } else {
      setError('Усі поля необхідно заповнити.');
      onToggleSnackBar();
    }
  };

  const openCamera = async () => {
    let result = await ImagePicker.launchImageLibraryAsync();
    if (!result.canceled) {
      const manipResult = await manipulateAsync(
        result.uri,
        [{ resize: { width: 300 } }],
        { compress: 0.5, base64: true },
      );
      setBase64(manipResult.base64);
    }
  };

  return {
    models: {
      hide,
      setHide,
      mode,
      setMode,
      title,
      setTitle,
      description,
      setDescription,
      date,
      setDate,
      users,
      setUsers,
      maxPrice,
      setMaxPrice,
      base64,
      setBase64,
      visible,
      setVisible,
      error,
      setError,
      imageUri,
      setImageUri,
      secondPage,
      setSecondPage,
    },
    commands: {
      requiredFields,
      openCamera,
      onDismissSnackBar,
      onToggleSnackBar,
    },
  };
}