import React from 'react';
import {
  FlatList,
  Image,
  View,
  ScrollView,
} from 'react-native';
import styled from 'styled-components/native';
import TextComponent from '../../../components/TextComponent';

import {
  fetchSingleHoliday,
} from '../../../store/slices/holidaysSlice';
import IconButtonComponent from '../../../components/IconButtonComponent';
import SnackComponent from '../../../components/SnackComponent';
import { useSinglePostScreen } from './useSinglePostScreen';
import HolidayComponent from '../../../components/HolidayComponent';
import { useMainScreen } from '../../main/MainScreen/useMainScreen';

const MainContainer = styled.View`
  flex: 1;
  background: white;
`;

const SinglePostScreen = ({ route, navigation }) => {
  const {
    models: { dispatch, holidaysList },
    commands: { leaveFavorite, addFavorite },
  } = useMainScreen();

  const {
    models: { singleHoliday, user, visible, error },
    commands: {
      onDismissSnackBar,
      enjoyUser,
      leaveUser,
      closeHoliday,
      startHoliday,
    },
  } = useSinglePostScreen({ navigation, route });

  React.useEffect(() => {
    dispatch(fetchSingleHoliday(singleHoliday._id));
  }, [holidaysList]);

  return (
    <MainContainer>
      <SnackComponent top={'55px'} error={error} visible={visible}
                      onDismissSnackBar={onDismissSnackBar}/>
      <View style={{ height: '33%' }}>
        <HolidayComponent buttonFavoriteAdd={async () => {
          await addFavorite(singleHoliday);
          let newSingle = holidaysList.find(
            (el) => el._id === singleHoliday._id);
        }} buttonFavoriteLeave={() => {leaveFavorite(singleHoliday);}}
                          date={singleHoliday.date} title={singleHoliday.title}
                          description={singleHoliday.description}
                          base64={singleHoliday.base64}
                          users={singleHoliday.users} user={user}
                          favorite={singleHoliday.favorite}
                          item={singleHoliday}/>
      </View>

      <View style={{ paddingHorizontal: 15, maxHeight: 102 }}>
        <TextComponent fontSize={'17px'} color={'#0C0012'}>Опис:</TextComponent>
        <ScrollView>
          <TextComponent fontSize={'15px'}
                         color={'#0C0012'}>{singleHoliday.description}</TextComponent>
        </ScrollView>
      </View>
      <View style={{ flex: 1 }}>
        <View style={{
          height: '80%',
          paddingTop: 10,
          paddingHorizontal: 15,
        }}>
          <TextComponent fontSize={'17px'}
                         color={'#0C0012'}>Учасники:</TextComponent>
          <FlatList style={{ paddingTop: 5 }} data={singleHoliday.users}
                    renderItem={({ item }) => (
                      <View style={{
                        flexDirection: 'row',
                        display: 'flex',
                        alignItems: 'center',
                      }}>
                        <Image style={{ width: 75, height: 75 }}
                               source={{ uri: item.userAvatar }}/>
                        <TextComponent fontSize={'17px'}
                                       color={'#0C0012'}>{item.firstname} {item.secondname}</TextComponent>
                      </View>
                    )}/>
        </View>
        <View style={{ height: '20%' }}>
          <View style={{
            height: '100%',
            display: 'flex',
            flexDirection: 'row',
            alignItems: 'center',
            justifyContent: 'center',
          }}>
            {user.role === 'admin' &&
              <IconButtonComponent icon={'delete'} pressButton={() => {
                closeHoliday(singleHoliday);
              }}/>
            }
            {singleHoliday.users.find(e => e.userId === user._id) &&
              <IconButtonComponent disabled={!singleHoliday.isStarted}
                                   icon={'assistant'}
                                   pressButton={() => {
                                     navigation.navigate('YourAssistant');
                                   }}/>
            }
            {user.role === 'admin' &&
              <IconButtonComponent icon={'start'} pressButton={() => {
                startHoliday(singleHoliday);
              }}/>
            }
          </View>
        </View>
      </View>
    </MainContainer>
  );
};

export default SinglePostScreen;