import { useDispatch, useSelector } from 'react-redux';
import React from 'react';
import axios from 'axios';
import {
  fetchHolidays,
  fetchSingleHoliday,
} from '../../../store/slices/holidaysSlice';
import { Alert } from 'react-native';

export function useSinglePostScreen ({ navigation, route }) {

  const dispatch = useDispatch();
  const singleHoliday = useSelector(state => state.holidaySlice.singleHoliday);
  const user = useSelector(state => state.holidaySlice.user);
  const [visible, setVisible] = React.useState(false);
  const [error, setError] = React.useState('Number of users must be even');

  const onToggleSnackBar = () => setVisible(!visible);
  const onDismissSnackBar = () => setVisible(false);

  const enjoyUser = (party) => {
    axios.put(`${process.env.API}/holidays`, {
      operation: 'add',
      holidayId: party._id,
      userId: user._id,
      userAvatar: user.userAvatar,
      firstname: user.firstname,
      secondname: user.secondname,
      notificationToken: user.notificationToken,
    }).then(async () => {
      await dispatch(fetchHolidays());
      await dispatch(fetchSingleHoliday(party._id));
    }).catch((e) => {console.log(e);});
  };

  const leaveUser = (party) => {
    axios.put(`${process.env.API}/holidays`, {
      operation: 'delete',
      holidayId: party._id,
      userId: user._id,
    }).then(async () => {
      await dispatch(fetchHolidays());
      await dispatch(fetchSingleHoliday(party._id));
    }).catch((e) => {console.log(e);});
  };

  const closeHoliday = (party) => {
    Alert.alert(
      'Підтвердіть',
      'Ви впевнені?',
      [
        {
          text: 'Yes',
          onPress: () => {
            axios.put(`${process.env.API}/holidays`, {
              operation: 'remove',
              holidayId: party._id,
              userId: user._id,
            }).then(async () => {
              await dispatch(fetchHolidays());
              navigation.navigate('Main');
            }).catch((e) => {console.log(e);});
          },
        },
        {
          text: 'No',
        },
      ],
    );
  };

  const startHoliday = (party) => {
    Alert.alert(
      'Confirm',
      'Are you sure you want to start the event?',
      [
        {
          text: 'Yes',
          onPress: () => {
            if (party.users.length % 2 === 0 ||
              (party.mode !== 'default' && party.users.length > 1)) {
              const body = {
                operation: 'start',
                isStarted: party.isStarted,
                title: party.title,
                description: party.description,
                date: party.date,
                maxPrice: party.maxPrice,
                base64: party.base64,
                users: party.users,
                startUsers: party.startUsers,
                partyId: party._id,
                mode: party.mode,
              };
              axios.post(`${process.env.API}/holidays`, body).then(async () => {
                await dispatch(fetchHolidays());
                await dispatch(fetchSingleHoliday(party._id));
              }).then(async () => {
                let arrayTokens = [];
                singleHoliday.users.forEach((el) => {
                  if (el.notificationToken) {
                    arrayTokens.push(el.notificationToken);
                  }
                });
                await axios.post('https://exp.host/--/api/v2/push/send', {
                  'to': arrayTokens,
                  'title': `${singleHoliday.title} скоро почнеться!`,
                  'body': 'Дізнайтесь і`мя свого напарника...',
                }, {
                  headers: {
                    'host': 'exp.host',
                    'accept': 'application/json',
                    'accept-encoding': 'gzip, deflate',
                    'content-type': 'application/json',
                  },
                });
              }).catch((e) => {console.log(e);});
            } else {
              onToggleSnackBar();
            }
          },
        },
        {
          text: 'No',
        },
      ],
    );
  };

  return {
    models: { singleHoliday, user, visible, error, setError, setVisible },
    commands: {
      onToggleSnackBar,
      onDismissSnackBar,
      enjoyUser,
      leaveUser,
      closeHoliday,
      startHoliday,
    },
  };
}