import React from 'react';
import {
  View,
  TouchableHighlight,
  Keyboard,
} from 'react-native';
import styled from 'styled-components/native';
import InputComponent from '../../../components/InputComponent';
import TextComponent from '../../../components/TextComponent';
import NumericInput from 'react-native-numeric-input';
import SnackComponent from '../../../components/SnackComponent';
import { useCreateWishScreen } from './useCreateWishScreen';
import ButtonComponent from '../../../components/ButtonComponent';

const InputContainer = styled.View`
  flex: 1;
  display: flex;
  width: 100%;
  align-items: center;
  padding-top: 20px;
`;
const MaxPrice = styled.View`
  flex-direction: row;
  display: flex;
  width: 80%;
  align-items: center;
  justify-content: space-between;
  height: 60px;
  background-color: transparent;
`;

const CreateWishScreen = ({ navigation }) => {

  const {
    models: {
      price,
      priority,
      title,
      url,
      visible,
      error,
      setUrl,
      setTitle,
      setPriority,
      setPrice,
      isLoadingRequest,
    },
    commands: {
      onDismissSnackBar, addWish,
    },
  } = useCreateWishScreen({ navigation });

  return (
    <TouchableHighlight underlayColor="transparent" activeOpacity={1}
                        onPress={() => {Keyboard.dismiss();}}
                        style={{ flex: 1, backgroundColor: 'white' }}>
      <View style={{ flex: 1 }}>
        <SnackComponent error={error} visible={visible}
                        onDismissSnackBar={onDismissSnackBar}/>
        <InputContainer>
          <TextComponent fontSize={'18px'}>Створіть своє власне
            бажання</TextComponent>
          <InputComponent
            marginTop={15}
            value={title}
            onChangeText={(title) => {setTitle(title);}}
            inputSelect={() => {console.log('select');}}
            inputPass={() => {Keyboard.dismiss();}}
            placeholder="Ваше бажання"
          />
          <InputComponent
            value={url}
            onChangeText={(url) => {setUrl(url);}}
            marginTop={15}
            placeholder="Посилання на бажання"
            inputSelect={() => {console.log('select');}}
            inputPass={() => {Keyboard.dismiss();}}
          />
          <MaxPrice style={{
            marginTop: 15,
            shadowColor: '#171717',
            shadowOffset: { width: 0, height: 3 },
            shadowOpacity: 0.2,
            shadowRadius: 2,
          }}>
            <TextComponent fontSize={16}>Ціна:</TextComponent>
            <NumericInput
              iconStyle={{
                backgroundColor: '#F3E4FF',
                borderRadius: 20,
                padding: 7,
                fontSize: 20,
                textAlign: 'center',
              }}
              value={price}
              leftButtonBackgroundColor="transparent"
              rightButtonBackgroundColor="transparent"
              borderColor="transparent"
              onChange={value => setPrice(value)}
            />
          </MaxPrice>
          <MaxPrice style={{
            marginTop: 15,
            shadowColor: '#171717',
            shadowOffset: { width: 0, height: 3 },
            shadowOpacity: 0.2,
            shadowRadius: 2,
          }}>
            <TextComponent fontSize={16}>Бажаність*:</TextComponent>
            <NumericInput
              iconStyle={{
                backgroundColor: '#F3E4FF',
                borderRadius: 20,
                padding: 7,
                fontSize: 20,
                textAlign: 'center',
              }}
              maxValue={3}
              minValue={1}
              value={priority}
              leftButtonBackgroundColor="transparent"
              rightButtonBackgroundColor="transparent"
              borderColor="transparent"
              onChange={value => setPriority(value)}
            />
          </MaxPrice>
          <TextComponent width={'80%'} marginTop={15} fontSize={15}
                         color={'#ACACAC'}>*Ви можете встановити пріоритетність
            цього подрунку. Від 1 до 3 балів.</TextComponent>
          <ButtonComponent isLoadingRequest={isLoadingRequest} mt={'30px'}
                           width={'50%'}
                           buttonPress={() => {addWish();}}>Добавити</ButtonComponent>
        </InputContainer>
      </View>
    </TouchableHighlight>
  );
};

export default CreateWishScreen;