import { useDispatch, useSelector } from 'react-redux';
import React from 'react';
import axios from 'axios';
import { saveUser } from '../../../store/slices/holidaysSlice';
import { AsyncStorage } from 'react-native';

export function useCreateWishScreen ({ navigation }) {

  const dispatch = useDispatch();
  const user = useSelector(state => state.holidaySlice.user);

  const [price, setPrice] = React.useState(null);
  const [priority, setPriority] = React.useState(1);
  const [title, setTitle] = React.useState('');
  const [url, setUrl] = React.useState('');
  const [visible, setVisible] = React.useState(false);
  const [error, setError] = React.useState('');
  const [isLoadingRequest, setisLoadingRequest] = React.useState(false);

  const onToggleSnackBar = () => setVisible(!visible);
  const onDismissSnackBar = () => setVisible(false);
  const addWish = async () => {
    setError('');
    if (title.length && url.length && price > 0) {
      setisLoadingRequest(true);
      const body = {
        operation: 'add',
        userId: user._id,
        title,
        url,
        priority,
        price,
      };
      console.log(body);

      axios.put(`${process.env.API}/login`, body).then(async resp => {
        const updatedUser = resp.data;
        updatedUser.token = user.token;
        dispatch(saveUser(updatedUser));
        try {
          await AsyncStorage.setItem(
            'user',
            JSON.stringify(updatedUser),
          );
        } catch (error) {
          console.log('this');
          console.log(error);
        }
        setisLoadingRequest(false);
        navigation.goBack();
      });
    } else {
      setError('Усі поля необхідно заповнити.');
      onToggleSnackBar();
    }
  };

  return {
    models: {
      price,
      priority,
      title,
      url,
      visible,
      error,
      setError,
      setVisible,
      setUrl,
      setTitle,
      setPriority,
      setPrice,
      user,
      isLoadingRequest,
    },
    commands: {
      onToggleSnackBar, onDismissSnackBar, addWish,
    },
  };
}