import React from 'react';
import {
  FlatList,
  RefreshControl,
  View,
  TouchableOpacity, Image,
} from 'react-native';
import { fetchSingleHoliday } from '../../../store/slices/holidaysSlice';
import { fetchHolidays } from '../../../store/slices/holidaysSlice';
import HolidayComponent from '../../../components/HolidayComponent';
import ButtonCreateComponent from '../../../components/ButtonCreateComponent';
import { useMainScreen } from './useMainScreen';
import styled from 'styled-components/native';
import TextComponent from '../../../components/TextComponent';
import { MaterialIcons } from '@expo/vector-icons';

const LogoContainer = styled.View`
  display: flex;
  justify-content: center;
  align-items: center;
`;

const LogoTitle = styled.View`
  flex-direction: row;
  width: 100%;
  display: flex;
  justify-content: space-between;
  padding-top: 15px;
  padding-left: 15px;
  padding-right: 15px;
  padding-bottom: 5px;
`;

const MainScreen = ({ navigation }) => {

  const {
    models: { dispatch, isLoading, holidaysList, user },
  } = useMainScreen();

  return (
    <View style={{ flex: 1, backgroundColor: 'white', paddingTop: '10%' }}>
      {user && user.role === 'admin' &&
        <ButtonCreateComponent
          pressButton={() => {navigation.navigate('CreateHoliday');}}/>
      }
      <LogoContainer>
        <Image style={{ width: 100, height: 60 }}
               source={require('./../../../../assets/groupbwt/bwtAuth.png')}/>
        <LogoTitle>
          <TextComponent>Свята</TextComponent>
          <MaterialIcons name="notifications-none" size={30} color="#0C0012"/>
        </LogoTitle>
      </LogoContainer>
      {holidaysList.length ?
        <FlatList
          refreshControl={<RefreshControl refreshing={isLoading}
                                          onRefresh={() => dispatch(
                                            fetchHolidays())}/>}
          data={[...holidaysList]}
          renderItem={({ item }) => (
            <TouchableOpacity onPress={() => {
              dispatch(fetchSingleHoliday(item._id));
              navigation.navigate('SinglePost', item);
            }}>
              <HolidayComponent
                date={item.date} title={item.title}
                description={item.description}
                base64={item.base64} users={item.users}
                user={user} favorite={item.favorite}
                item={item}
              />
            </TouchableOpacity>
          )}/> : null}
    </View>
  );
};

export default MainScreen;