import React from 'react';
import MainScreen from '../MainScreen/MainScreen';
import SettingsScreen from '../../settings/SettingsScreen/SettingsScreen';
import WishListScreen from '../WishListScreen/WishListScreen';
import Ionicons from '@expo/vector-icons/Ionicons';
import { useMainTabsScreen } from './useMainTabsScreen';
import { fetchHolidays } from '../../../store/slices/holidaysSlice';
import FavoriteScreen from '../../settings/FavoriteScreen/FavoriteScreen';

const MainTabsScreen = ({ navigation }) => {

  const {
    models: { Tab, dispatch },
    commands: { asyncFunction },
  } = useMainTabsScreen({ navigation });

  React.useEffect(() => {
    asyncFunction();
  }, []);

  return (
    <Tab.Navigator screenOptions={({ route }) => ({
      tabBarStyle: {
        borderTopWidth: 1,
      },
      tabBarIcon: ({ focused, color, size }) => {
        let iconName;
        if (route.name === 'Свята') {
          iconName = focused ? 'home-sharp' : 'home-outline';
        } else if (route.name === 'Налаштування') {
          iconName = focused ? 'ios-person' : 'ios-person-outline';
        } else if (route.name === 'Обрані свята') {
          iconName = focused ? 'md-star-sharp' : 'md-star-outline';
        } else if (route.name === 'Список бажань') {
          iconName = focused ? 'list-sharp' : 'list-outline';
        }
        return <Ionicons name={iconName} size={size} color={color}/>;
      },
      tabBarActiveTintColor: '#7913af',
      tabBarInactiveTintColor: '#595959',
      tabBarShowLabel: false,
    })}>
      <Tab.Screen listeners={{
        tabPress: () => {dispatch(fetchHolidays());},
      }} name="Свята" component={MainScreen} options={{
        headerShown: false,
      }}/>
      <Tab.Screen name="Список бажань" component={WishListScreen} options={{
        headerTitleStyle: { color: '#0C0012' },
        headerShadowVisible: false,
        headerBackTitle: 'Назад',
        headerTitleAlign: 'center',
      }}/>
      <Tab.Screen name="Обрані свята" component={FavoriteScreen} options={{
        headerTitleStyle: {
          color: '#0C0012',
        },
        headerTitleAlign: 'center',
        headerShadowVisible: false,
      }}/>
      <Tab.Screen name="Налаштування" component={SettingsScreen} options={{
        headerTitleAlign: 'center',
        headerTitleStyle: { color: '#0C0012' },
      }}/>
    </Tab.Navigator>
  );
};

export default MainTabsScreen;