import React from 'react';
import {
  TouchableHighlight,
  TouchableOpacity,
  View,
} from 'react-native';
import styled from 'styled-components/native';
import TextComponent from '../../../components/TextComponent';
import WishComponent from '../../../components/WishComponent';
import { SwipeListView } from 'react-native-swipe-list-view';
import Ionicons from '@expo/vector-icons/Ionicons';
import { useWishListScreen } from './useWishListScreen';
import { MaterialIcons } from '@expo/vector-icons';
import ButtonComponent from '../../../components/ButtonComponent';
import { AntDesign } from '@expo/vector-icons';

const ButtonContainer = styled.View`
  position: absolute;
  width: 100%;
  bottom: 10px;
  display: flex;
  justify-content: center;
  align-items: center;
`;
const ListContainer = styled.View`
`;
const CenterContainer = styled.View`
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
  padding: 20px;
  flex-direction: row;
`;

const TwoButtonContainer = styled.View`
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: space-between;
  flex-direction: row;
`;

const WishListScreen = ({ navigation }) => {

  const {
    models: { user },
    commands: { removeWish },
  } = useWishListScreen({ navigation });

  return (
    <View style={{ flex: 1, backgroundColor: 'white' }}>
      {user.wishList && <View style={{ flex: 1 }}>
        <ListContainer>
          <CenterContainer>
            <AntDesign name="gift" size={26} color="#7B04BB"/>
            <TextComponent fontSize={'18px'} pl={'10px'} color="#0C0012">У
              вашому списку: {user.wishList.length} бажання.</TextComponent>
          </CenterContainer>
          <SwipeListView
            style={{ height: '75%' }}
            leftOpenValue={75}
            rightOpenValue={-75}
            data={user.wishList}
            renderItem={({ item }) => (
              <TouchableOpacity activeOpacity={1}>
                <WishComponent title={item.title} url={item.url}
                               price={item.price}
                               priority={item.priority}/>
              </TouchableOpacity>
            )}
            renderHiddenItem={(data, rowMap) => (
              <TwoButtonContainer>
                <TouchableHighlight style={{
                  width: 75,
                  height: '100%',
                  backgroundColor: '#6DAD04',
                  display: 'flex',
                  alignItems: 'center',
                  justifyContent: 'center',
                }}><Ionicons name="settings" size={24}
                             color="white"/></TouchableHighlight>
                <TouchableHighlight onPress={() => {
                  rowMap[data.item.key].closeRow();
                  removeWish(data);
                }} style={{
                  width: 75,
                  height: '100%',
                  backgroundColor: 'red',
                  display: 'flex',
                  alignItems: 'center',
                  justifyContent: 'center',
                }}><MaterialIcons name="delete-forever" size={30}
                                  color="white"/></TouchableHighlight>
              </TwoButtonContainer>
            )}
          />
        </ListContainer>
        <ButtonContainer>
          <ButtonComponent buttonPress={() => {
            navigation.navigate('CreateWish');
          }}>Добавити</ButtonComponent>
        </ButtonContainer>
      </View>}
    </View>
  )
    ;
};

export default WishListScreen;