import React from 'react';
import {
  FlatList,
  RefreshControl,
  TouchableOpacity,
  View,
} from 'react-native';
import {
  fetchHolidays,
  fetchSingleHoliday,
} from '../../../store/slices/holidaysSlice';
import HolidayComponent from '../../../components/HolidayComponent';
import { useMainScreen } from '../../main/MainScreen/useMainScreen';
import TextComponent from '../../../components/TextComponent';

const FavoriteScreen = ({ navigation }) => {

  const {
    models: { dispatch, isLoading, holidaysList, user },
  } = useMainScreen();

  return (
    <View style={{ flex: 1, backgroundColor: 'white' }}>
      {holidaysList.filter(x => x.favorite.some(y => y === user._id)).length ?
        <FlatList
          refreshControl={<RefreshControl refreshing={isLoading}
                                          onRefresh={() => dispatch(
                                            fetchHolidays())}/>}
          data={[
            ...holidaysList.filter(x => x.favorite.some(y => y === user._id))]}
          renderItem={({ item }) => (
            <TouchableOpacity onPress={() => {
              dispatch(fetchSingleHoliday(item._id));
              navigation.navigate('SinglePost', item);
            }}>
              <HolidayComponent
                date={item.date} title={item.title}
                description={item.description}
                base64={item.base64} users={item.users}
                user={user} favorite={item.favorite}
                item={item}
              />
            </TouchableOpacity>
          )}/> : <View style={{
          flex: 1,
          width: '90%',
          display: 'flex',
          alignSelf: 'center',
          marginTop: 15,
        }}>
          <TextComponent fontSize={'17px'}>На жаль у вас немає свят у яких ви
            зацікавлені</TextComponent>
        </View>}
    </View>
  );
};

export default FavoriteScreen;