import React from 'react';
import TextComponent from '../../../components/TextComponent';
import styled from 'styled-components/native';
import InputComponent from '../../../components/InputComponent';
import { ActivityIndicator, Keyboard, View } from 'react-native';
import ButtonComponent from '../../../components/ButtonComponent';
import axios from 'axios';
import { useMyAccountScreen } from './useMyAccountScreen';

const MainContainer = styled.TouchableHighlight`
  background: white;
  flex: 1;
  width: 100%;
  padding-left: 5%;
  padding-right: 5%;
  align-self: center;
  padding-top: 10px;
  padding-bottom: 10px;
`;
const MainContainerName = styled.View`
  margin-top: 15px;
`;
const AvatarRow = styled.View`
  margin-top: 15px;
  flex-direction: row;
  flex-wrap: wrap;
`;
const AvatarColumn = styled.TouchableHighlight`
  width: 25%;
  border: ${props => props.active
          ? '2px solid #F3E4FF'
          : '2px solid transparent'};
  border-radius: 5px;
`;
const Avatar = styled.Image`
  width: 100%;
  height: 100px;
`;

const ButtonContainer = styled.View`
  position: absolute;
  bottom: 0;
  width: 100%;
  justify-content: center;
  display: flex;
  align-items: center;
`;

const Indicator = styled.View`
  width: 100%;
  height: 200px;
  display: flex;
  justify-content: center;
  align-items: center;
`;

const MyAccountScreen = ({ navigation }) => {

  const {
    models: {
      firstname,
      secondname,
      picture,
      isLoadingRequest,
      setFirstname,
      setSecondname,
      setPicture,
      setUserAvatar,
      user,
    },
    commands: { setActive, sendSave },
  } = useMyAccountScreen({ navigation });

  React.useEffect(() => {
    setFirstname(user.firstname);
    setSecondname(user.secondname);
    let operation;
    if (user.isMan) {
      operation = 'avatarsForMan';
    } else {
      operation = 'avatarsForWomen';
    }
    axios.post(`${process.env.API}/settings`, { operation }).then((resp) => {
      let body = resp.data;
      let startIndex = 0;
      body.forEach((el, index) => {
        if (el.uri === user.userAvatar) {
          startIndex = index;
        }
      });
      body[startIndex].active = true;
      setPicture(body);
      setUserAvatar(body[startIndex].uri);
    });
  }, []);

  return (
    <MainContainer onPress={() => Keyboard.dismiss()}
                   underlayColor="transparent" activeOpacity={1}>
      <View style={{ flex: 1 }}>
        <MainContainerName>
          <TextComponent>Ваше ім'я</TextComponent>
          <TextComponent color={'#595959'} fontSize={'16px'}>Ви можете
            використовувати
            псевдонім</TextComponent>
          <InputComponent marginTop={'15px'} value={firstname}
                          onChangeText={(value) => {setFirstname(value);}}
                          inputSelect={() => {
                            console.log('select');
                          }}></InputComponent>
        </MainContainerName>
        <MainContainerName>
          <TextComponent>Ваше прізвище</TextComponent>
          <InputComponent marginTop={'15px'} value={secondname}
                          onChangeText={(value) => {setSecondname(value);}}
                          inputSelect={() => {
                            console.log('select');
                          }}></InputComponent>
        </MainContainerName>
        <MainContainerName>
          <TextComponent>Ваш аватар</TextComponent>
          {picture.length > 0 ? <AvatarRow>
              {picture.map((el, index) => (
                <AvatarColumn active={el.active} underlayColor="transparent"
                              activeOpacity={1} onPress={() => setActive(index)}>
                  <Avatar resizeMode="contain" source={{ uri: el.uri }}/>
                </AvatarColumn>
              ))}
            </AvatarRow>
            : <Indicator>
              <ActivityIndicator size={75} color={'#F3E4FF'}/>
            </Indicator>}
        </MainContainerName>
        <ButtonContainer>
          <ButtonComponent isLoadingRequest={isLoadingRequest}
                           buttonPress={sendSave}>Зберегти</ButtonComponent>
        </ButtonContainer>
      </View>
    </MainContainer>
  );
};

export default MyAccountScreen;