import { createSlice, createAsyncThunk } from '@reduxjs/toolkit';
import axios from 'axios';

export const fetchHolidays = createAsyncThunk(
  'holidays/fetchCocktails',
  async function () {

    const response = await axios.get(
      `${process.env.API}/holidays`);
    return response.data;
  },
);

const holidaysSlice = createSlice({
  name: 'holidays',
  initialState: {
    singleHoliday: {},
    holidaysList: [],
    isLoading: false,
    err: null,
    status: '',
    user: false,
  },
  reducers: {
    fetchSingleHoliday (state, action) {
      state.holidaysList.forEach((el) => {
        if (el._id === action.payload) {
          state.singleHoliday = el;
        }
      });
    },
    saveUser (state, action) {
      const updateUser = action.payload;
      updateUser.wishList.sort(function (a, b) {
        return b.priority - a.priority;
      });
      state.user = updateUser;
    },
    cleanUser (state) {
      state.user = false;
    },
    saveHolidays (state, action) {
      state.holidaysList = action.payload;
    },
    changeLoad (state) {
      console.log('loading');
      state.status = 'loading..';
    },
    finishLoad (state) {
      console.log('finish');
      state.status = 'resolved';
    },
  },
  extraReducers: {
    [fetchHolidays.pending]: (state, action) => {
      state.err = null;
      state.isLoading = true;
    },
    [fetchHolidays.fulfilled]: (state, action) => {
      state.holidaysList = action.payload;
      state.err = null;
      state.isLoading = false;
    },
    [fetchHolidays.rejected]: (state, action) => {
      state.status = 'error';
      state.err = 'error';
      console.log('holidays fetch error');
    },
  },
});

export default holidaysSlice.reducer;
export const {
  saveHolidays,
  saveUser,
  cleanUser,
  fetchSingleHoliday,
} = holidaysSlice.actions;